""" Use candian_data module to read from CD and write temperature data. v%s
Copyright (C) 1999 Bernhard Reiter 
<bernhard@ffii.org> http://www.uwm.edu/~bernhard/

Serves as an example file for getting data from a bunch of stations and 
writing it out in a special format. Note that the special format
is implemented as method to the class weather_station.
For us, of course, this was the real application.

The variable setting in the beginning control the behaviour of the
program. The canadian_data.py file has to be in the python module search
path (the current directory should be fine).

	License:
	--------
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
This source is Free Software under the GNU GPL License (see gpl.txt).
"""
__version__=0.3 
# initial 25.8.1999 Bernhard Reiter
# 27.8.1999 Bernhard
#	open outputfile as non binary
# 29.8.1999 Bernhard
#	added more documentation

import sys
import time
import fileinput
import string

import canadian_data

Topdirectory="H:/"	# where the topdirectory of the cd is
stationlistfilename="Stats25_Canada.dat"	# which station do we want
outputfilename="temperature_extracted.dat"	
#years=[1995]
years=[1995,1996,1997]

################################################################################
def waitforkey_on_windows():
        """on windows, wait for a keypress (good for console programs)"""
        if sys.platform=="win32":
                import msvcrt
                sys.stderr.write("*** press any key ***\n")
                msvcrt.getch()
################################################################################


print "Looking for climate data at \"%s\" ..." % Topdirectory
stations=canadian_data.get_station_list(Topdirectory)
print "found %s stations" % len(stations)

#set up quickindex for stationnumbers
stationindex={}
for station in stations:
	stationindex[station.stationnumber]=station

print "Writing results out to %s:" % outputfilename
outputfile=open(outputfilename,"w")
outputfile.write("# Controlling Program: %s (v%s)\n" %(sys.argv[0],__version__))
outputfile.write("# Using module canadian_data v%s\n"%canadian_data.__version__)
outputfile.write("#\n")
outputfile.write("# Canadian CD at: " +  Topdirectory + "\n")
outputfile.write("# Stationlist: " +  stationlistfilename + "\n")
outputfile.write("# Years: " +  `years` + "\n")
outputfile.write("# run initiated: " + time.ctime(time.time()) + "\n" )
outputfile.write("#\n")

#for every station, we want
fileinputobject= fileinput.input(stationlistfilename)
try:
    for line in fileinputobject:
        line=string.strip(line)
        if line and stationindex.has_key(line):
    	# found our station -> write it out
            s=stationindex[line]
            for year in years:
                s.write_temperature_for_mark(outputfile,year)
                s.deactivate()
            sys.stdout.write(".")
finally: 
    fileinputobject.close()

outputfile.close()
print "\nDone."
waitforkey_on_windows()
